/* adv1.h: Cloak_of_Darkness - copyright Mike Arnautov 2022. Licensed under
 * GPL (version 3 or later) or the Modified BSD Licence, whichever
 * is asserted by the supplied LICENCE file.*/

#ifndef ADV1_H
#define ADV1_H
#define GAME_NAME "Cloak_of_Darkness"
#define GAME_VERSION "1.5"
#define GAME_ID "Cloak_of_Darkness version 1.5, 07 Feb 2022"
#define STYLE 12
#ifndef ADV01
#define GAME_DATE "07 Feb 2022"
#define ACDC_VERSION "12.46, 08 Mar 2022"
#if defined(MSDOS) || defined(_WIN32)
#  define PERSISTENT_DATA "_cloak_of_darkness.adp"
#  define CGINAME "_cloak_of_darkness"
#else
#  define PERSISTENT_DATA ".cloak_of_darkness.adp"
#  define CGINAME ".cloak_of_darkness"
#endif
#define DBNAME "cloak_of_darkness.dat"
#define OBJSIZE 1
#define LOCSIZE 1
#define VARSIZE 1
#define FOBJ 3
#define LOBJ 5
#define FLOC 6
#define LLOC 9
#define FVERB 10
#define LVERB 31
#define FVAR 32
#define LVAR 39
#define FTEXT 39
#define LTEXT 61
#define NOISE 19
#define KNOT 14
#define COMMA -28
#define SEMICOLON -30
#define INHAND 9
#define HERE 34
#define THERE 35
#define STATUS 32
#define ARG1 36
#define ARG2 37
#define ARG3 38
#define MOVED 0
#define ADVCONTEXT 33
#define NOWORD -1
#define BADWORD -2
#define AMBIGWORD -3
#define AMBIGTYPO -4
#define SCENEWORD -5
#define BADSYNTAX -6
#define NO_MATCH 98
#define NO_AMATCH 99
#define OBJ 0
#define LOC 1
#define VERB 2
#define PLAIN 0
#define DBSTATUS 0
#define LPROC 32
#define KEY(X) (value[36]==X || value[37]==X)
#define INIT_PROC p1
#define REPEAT_PROC p2
#endif
#define SW_START     037
#define SW_BREAK     036
#define HOLDER       035
#define IGNORE_EOL   032
#define NEST_TEXT    031
#define QUOTE_START  030
#define TAG_START    027
#define TAG_END      026
#define NBSP         025
#define BLOCK_START  024
#define BLOCK_END    023
#define CENTRE_START 022
#define VHOLDER      020
#define UTF8         1
#define VOCAB_SIZE 58
#define TEXT_BYTES 2628
#define USEQUERY 0
#endif
