// This is a game-spcific info string for QT build of Cloak.
//
#define GAME "Cloak"
#define GAMEINFO "<b>" GAME "</b> " \
"is Mike Arnautov's implementation of the test nano-adventure " \
"\"<b>Cloak of Darkness</b>\"" \
"<br> <br>" \
"Please see Roger Firth's site for imlpementations using other " \
"authoring systems: " \
"<a href='http://www.firthworks.com/roger/cloak/index.html'>" \
"http://www.firthworks.com/roger/cloak/index.html</a>."
