/* adv3.h: Cloak_of_Darkness - copyright Mike Arnautov 2022. Licensed under
 * GPL (version 3 or later) or the Modified BSD Licence, whichever
 * is asserted by the supplied LICENCE file.*/

extern void fake(int x, int y);
extern int p0(void);
extern int p1(void);
extern int p2(void);
extern int p3(void);
extern int p4(void);
extern int p5(void);
extern int p6(void);
extern int p7(void);
extern int p8(void);
extern int p9(void);
extern int p10(void);
extern int p11(void);
extern int p12(void);
extern int p13(void);
extern int p14(void);
