/* adv4.h: Cloak_of_Darkness - copyright Mike Arnautov 2022. Licensed under
 * GPL (version 3 or later) or the Modified BSD Licence, whichever
 * is asserted by the supplied LICENCE file.*/

int (*procs[])() = {
p0,p0,p0,p0,p0,p0,p8,p4,p3,p0,p7,
p0,p0,p0,p0,p0,p0,p0,p0,p0,p10,p12,
p14,p11,p6,p9,p13,p0,p0,p0,p0,p0,p0 };
